==> pde-2.12.0.tgz: package/lib/hooks/useFeature.js <==
import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext';
import { getPlatformStrategy } from './platformStrategies';
var VARIATION_NAME_ON = 'On State';
var VARIATION_NAME_OFF = 'Off State';
/**
 * track feature flag's own Experiment Viewed event
 * @param {object} param
 * @param {boolean} param.isActive
 * @param {function} param.trackExperimentViewed
 * @param {string} param.featureKey
 */

var trackFeatureFlagViewed = function trackFeatureFlagViewed(_ref) {
  var isActive = _ref.isActive,
      trackExperimentViewed = _ref.trackExperimentViewed,
      featureKey = _ref.featureKey;
  var variationName = isActive ? VARIATION_NAME_ON : VARIATION_NAME_OFF;
  trackExperimentViewed({
    experimentName: featureKey,
    variationName: variationName
  });
};
/**
 * track every linked experiment's Experiment Viewed event
 * @param {object} param
 * @param {linkedExperiments} string[] feature tests using the current feature flag
 * @param {function} trackExperimentViewed
 * @param {function} getExperimentVariation gets user variation linked to experiment
 * @param {object} attributes user attributes to take into account for its segmentation
 * @param {object} pde
 */


var trackLinkedExperimentsViewed = function trackLinkedExperimentsViewed(_ref2) {
  var linkedExperiments = _ref2.linkedExperiments,
      trackExperimentViewed = _ref2.trackExperimentViewed,
      getExperimentVariation = _ref2.getExperimentVariation,
      attributes = _ref2.attributes,
      pde = _ref2.pde;
  if (!linkedExperiments) return;
  linkedExperiments.forEach(function (experimentName) {
    var variationName = getExperimentVariation({
      experimentName: experimentName,
      pde: pde,
      attributes: attributes
    });
    trackExperimentViewed({
      variationName: variationName,
      experimentName: experimentName
    });
  });
};
/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @param {string} [queryString] test purposes only
 * @return {{isActive: boolean}}
 */


export default function useFeature(featureKey, attributes, queryString) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useFeature] sui-pde provider is required to work');
  var strategy = getPlatformStrategy();
  var forcedValue = strategy.getForcedValue({
    key: featureKey,
    queryString: queryString
  });

  try {
    if (forcedValue) {
      return {
        isActive: forcedValue === 'on',
        linkedExperiments: []
      };
    }

    var _pde$isFeatureEnabled = pde.isFeatureEnabled({
      featureKey: featureKey,
      attributes: attributes
    }),
        isActive = _pde$isFeatureEnabled.isActive,
        linkedExperiments = _pde$isFeatureEnabled.linkedExperiments;

    var variables = pde.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes
    });
    trackFeatureFlagViewed({
      isActive: isActive,
      trackExperimentViewed: strategy.trackExperiment,
      featureKey: featureKey
    });
    trackLinkedExperimentsViewed({
      linkedExperiments: linkedExperiments,
      trackExperimentViewed: strategy.trackExperiment,
      getExperimentVariation: strategy.getVariation,
      pde: pde,
      attributes: attributes
    });
    return {
      isActive: isActive,
      variables: variables
    };
  } catch (error) {
    console.error(error);
    return {
      isActive: false,
      variables: {}
    };
  }
}

==> pde-2.19.0.tgz: package/lib/hooks/useFeature.js <==
import { useContext } from 'react';
import PdeContext from '../contexts/PdeContext.js';
import { getPlatformStrategy } from './common/platformStrategies.js';
var VARIATION_NAME_ON = 'On State';
var VARIATION_NAME_OFF = 'Off State';
/**
 * track feature flag's own Experiment Viewed event
 * @param {object} param
 * @param {boolean} param.isActive
 * @param {function} param.trackExperimentViewed
 * @param {string} param.featureKey
 */

var trackFeatureFlagViewed = function trackFeatureFlagViewed(_ref) {
  var isActive = _ref.isActive,
      trackExperimentViewed = _ref.trackExperimentViewed,
      featureKey = _ref.featureKey;
  var variationName = isActive ? VARIATION_NAME_ON : VARIATION_NAME_OFF;
  trackExperimentViewed({
    experimentName: featureKey,
    variationName: variationName
  });
};
/**
 * track every linked experiment's Experiment Viewed event
 * @param {object} param
 * @param {linkedExperiments} string[] feature tests using the current feature flag
 * @param {function} trackExperimentViewed
 * @param {object} attributes user attributes to take into account for its segmentation
 * @param {object} pde
 */


var trackLinkedExperimentsViewed = function trackLinkedExperimentsViewed(_ref2) {
  var linkedExperiments = _ref2.linkedExperiments,
      trackExperimentViewed = _ref2.trackExperimentViewed,
      attributes = _ref2.attributes,
      pde = _ref2.pde;
  if (!linkedExperiments) return;
  linkedExperiments.forEach(function (experimentName) {
    var variationName = pde.getVariation({
      experimentName: experimentName,
      pde: pde,
      attributes: attributes
    });
    trackExperimentViewed({
      variationName: variationName,
      experimentName: experimentName
    });
  });
};
/**
 * Hook to use a feature toggle
 * @param {string} featureKey
 * @param {object} attributes
 * @param {string} [queryString] test purposes only
 * @param {string} adapterId
 * @return {{isActive: boolean}}
 */


export default function useFeature(featureKey, attributes, queryString, adapterId) {
  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[useFeature] sui-pde provider is required to work');
  var strategy = getPlatformStrategy();
  var forcedValue = strategy.getForcedValue({
    key: featureKey,
    queryString: queryString
  });

  try {
    if (forcedValue) {
      return {
        isActive: forcedValue === 'on',
        linkedExperiments: []
      };
    }

    var _pde$isFeatureEnabled = pde.isFeatureEnabled({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    }),
        isActive = _pde$isFeatureEnabled.isActive,
        linkedExperiments = _pde$isFeatureEnabled.linkedExperiments;

    var variables = pde.getAllFeatureVariables({
      featureKey: featureKey,
      attributes: attributes,
      adapterId: adapterId
    });
    trackFeatureFlagViewed({
      isActive: isActive,
      trackExperimentViewed: strategy.trackExperiment,
      featureKey: featureKey
    });
    trackLinkedExperimentsViewed({
      linkedExperiments: linkedExperiments,
      trackExperimentViewed: strategy.trackExperiment,
      pde: pde,
      attributes: attributes
    });
    return {
      isActive: isActive,
      variables: variables
    };
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    return {
      isActive: false,
      variables: {}
    };
  }
}
